Documentation
=============

kanren is very new.  Documentation is still very sparse.  Forunately the basic interface is shared with some more mature projects and so you may find looking at the following sources of use.

[core.logic](https://github.com/clojure/core.logic/wiki/A-Core.logic-Primer) is a popular Clojure project with very similar syntax.

[The Reasoned Schemer](http://www.amazon.com/The-Reasoned-Schemer-Daniel-Friedman/dp/0262562146/) is a quick book on miniKanren, the original implementation in Scheme
